Plugins for gsm.app are defined by a named list with information about the
plugin. These can be loaded from a yaml file with gsm.app::plugin_Read().
We provide a ready-to-use plugin definition for this PD plugin.
Plugins for gsm.app are defined by a named list with information about the
plugin. These can be loaded from a yaml file with gsm.app::plugin_Read().
We provide a ready-to-use plugin definition for this PD plugin.